import React from "react";
import { Input, Ref } from "semantic-ui-react";
import { PureComponent, createRef } from "react";
import { func, node, string } from "prop-types";
import { mergeClasses } from "@orbit-ui/react-components-shared";
export class MultiSelectDropdownSearchInput extends PureComponent {
  constructor(...args) {
    super(...args);
    this._inputRef = createRef();

    this.handleChange = (event, {
      value
    }) => {
      const {
        onChange
      } = this.props;
      onChange(event, value, this.props);
    };
  }

  getClasses() {
    const {
      className
    } = this.props;
    return mergeClasses("colored", className);
  }

  render() {
    const {
      placeholder,
      icon
    } = this.props;
    return React.createElement(Ref, {
      innerRef: this._inputRef
    }, React.createElement(Input, {
      onChange: this.handleChange,
      placeholder: placeholder,
      icon: true,
      iconPosition: "left",
      className: this.getClasses(),
      autoComplete: "off"
    }, React.createElement("i", {
      className: "icon"
    }, icon), React.createElement("input", {
      type: "text",
      autoFocus: true
    })));
  }

}
MultiSelectDropdownSearchInput.propTypes = {
  /**
   * Called on text change.
   * @param {SyntheticEvent} event - React's original SyntheticEvent.
   * @param {string} value - New value.
   * @param {Object} props - All the props.
   * @returns {void}
   */
  onChange: func,

  /**
   * A custom React SVG component displayed before the text.
   */
  icon: node,

  /**
   * The placeholder text.
   */
  placeholder: string,

  /**
   * Additional classes.
   */
  className: string
};